@@ -1683,7 +1683,7 @@ def transmision_coeff(psi0,Nt,dt,v,z,k,z_position,path_to_save = None, final_tim
     ax.ticklabel_format(useOffset=False, useMathText=True, style='sci')
     ax.yaxis.set_major_formatter(FormatStrFormatter('%.2e'))
     ax.set_xlabel('Time simulation, in fsec')
-    ax.set_ylabel('Cumulative probabilty through the interface')
+    ax.set_ylabel('Probabilty through the interface')
 
     if final_time is None or final_time == 0:
         ax.plot(np.array(cons.sec2fs(dt * np.arange(0, Nt))), np.array(results[:,1]),
